@@ -1,9 +1,9 @@
-/*
+  /*
 ** Name:        wxsqlite3def.h
 ** Purpose:     wxWidgets wrapper around the SQLite3 embedded database library.
 ** Author:      Ulrich Telle
 ** Created:     2005-07-14
-** Copyright:   (c) 2005-2018 Ulrich Telle
+** Copyright:   (c) 2005-2021 Ulrich Telle
 ** License:     LGPL-3.0+ WITH WxWindows-exception-3.1
 */
 
@@ -40,10 +40,143 @@
   since wxWidgets 2.8.4) are used for the conversion. Special care has to be taken if external administration
   tools are used to modify the database contents, since not all of these tools operate in Unicode or UTF-8 mode.
 
+\note With the release of SQLite version 3.32.0 on May 22, 2020 critical changes to the public SQLite code finally took officially effect, although they weren't officially announced. They were introduced on Feb 7, 2020: ["Simplify the code by removing the unsupported and undocumented SQLITE_HAS_CODEC compile-time option"](https://www.sqlite.org/src/timeline?c=5a877221ce90e752). Since August 2020 a new implementation of an encryption extension, capable of supporting SQLite version 3.32.0 and later, is available as a separate project, [**SQLite3 Multiple Ciphers**](https://github.com/utelle/SQLite3MultipleCiphers). Starting with the release of **wxSQLite3 4.6.0** this new implementation will be used.
+
 \section version Version history
 
 <dl>
 
+<dt><b>4.6.9</b> - <i>April 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.2.4 (SQLite version 3.35.4)</i><br>
+
+</dd>
+<dt><b>4.6.8</b> - <i>March 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.2.3 (SQLite version 3.35.3)</i><br>
+
+</dd>
+<dt><b>4.6.7</b> - <i>March 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.2.2 (SQLite version 3.35.2)</i><br>
+
+</dd>
+<dt><b>4.6.6</b> - <i>March 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.2.1 (SQLite version 3.35.1)</i><br>
+
+</dd>
+<dt><b>4.6.5</b> - <i>March 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.2.0 (SQLite version 3.35.0)</i><br>
+Enabled new SQLite Math Extension<br>
+Fixed a memory leak in method wxSQLite3Database::GetTable<br>
+Adjusted build files (DLL builds with MinGW/GCC used wrong DLL file extension)<br>
+
+</dd>
+<dt><b>4.6.4</b> - <i>December 2020</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.1.3</i><br>
+Adjusted autotool build files to enable AES hardware support if available<br>
+
+</dd>
+<dt><b>4.6.3</b> - <i>December 2020</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.1.2</i><br>
+Adjusted build files for MinGW<br>
+
+</dd>
+<dt><b>4.6.2</b> - <i>December 2020</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.1.1</i><br>
+Upgrade to <i>SQLite version 3.34.0</i><br>
+Added method wxSQLite3Database::QueryTransactionState<br>
+
+</dd>
+<dt><b>4.6.1</b> - <i>October 2020</i></dt>
+<dd>
+Added SQLite VSV extension (Variably Separated Values)<br>
+
+</dd>
+<dt><b>4.6.0</b> - <i>August 2020</i></dt>
+<dd>
+Use SQLite encryption extension "SQLite3 Multiple Ciphers"<br>
+Upgrade to SQLite version 3.33.0<br>
+Added support for System.Data.SQLite's RC4 encryption<br>
+
+</dd>
+<dt><b>4.5.1</b> - <i>January 2020</i></dt>
+<dd>
+Upgrade to SQLite version 3.31.1<br>
+
+</dd>
+<dt><b>4.5.0</b> - <i>January 2020</i></dt>
+<dd>
+Upgrade to SQLite version 3.31.0<br>
+Modified API for wxSQLite3Database::CreateFunction methods<br>
+
+</dd>
+<dt><b>4.4.8</b> - <i>October 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.30.1<br>
+Adjusted encryption extension to support SQLite's shared cache mode<br>
+
+</dd>
+<dt><b>4.4.7</b> - <i>October 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.30.0<br>
+
+</dd>
+<dt><b>4.4.6</b> - <i>September 2019</i></dt>
+<dd>
+Fixed missing cipher application in method wxSQLite3Database::ReKey<br>
+
+</dd>
+<dt><b>4.4.5</b> - <i>August 2019</i></dt>
+<dd>
+Fixed broken compatibility with wxWidgets 2.8.12<br>
+
+</dd>
+<dt><b>4.4.4</b> - <i>August 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.29.0<br>
+Added SQLite logging support<br>
+Added build support for VS2019<br>
+Added CMake support (PR #63)<br>
+Updated build files to overcome problems with static builds (issue #73)<br>
+Eliminated duplication of error messages for different wxWidgets builds (PR #64)<br>
+Fixed missing call to progress callback in wxSQLite3Database::Restore (PR #66)<br>
+Fixed issue #58 with silently failing wxSQLite3Transaction::Commit method<br>
+Fixed issue with named collections which could result in crashes (PR #59)<br>
+
+</dd>
+<dt><b>4.4.3</b> - <i>May 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.28.0<br>
+
+</dd>
+<dt><b>4.4.2</b> - <i>February 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.27.2<br>
+
+</dd>
+<dt><b>4.4.1</b> - <i>February 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.27.1<br>
+
+</dd>
+<dt><b>4.4.0</b> - <i>December 2018</i></dt>
+<dd>
+Upgrade to SQLite version 3.26.0<br>
+Added support for the SQLCipher 4 database format<br>
+
+</dd>
+<dt><b>4.3.0</b> - <i>November 2018</i></dt>
+<dd>
+Upgrade to SQLite version 3.25.3<br>
+Adjusted encryption extension to support cipher configuration via database URI<br>
+
+</dd>
 <dt><b>4.2.0</b> - <i>October 2018</i></dt>
 <dd>
 Added method wxSQLite3Database::GetKeySalt to access the key salt of encrypted databases<br>
@@ -582,12 +715,13 @@ The following people have contributed to wxSQLite3:
 <li>Francesco Montorsi (enhancement of the build system)</li>
 <li>Neville Dastur (enhancement of the method TableExists)</li>
 <li>Tobias Langner (RAII class for managing transactions)</li>
+<li>Deamhan (CMake support and various bug fixes)</li>
 </ul>
 
  */
 
-#ifndef _WX_SQLITE3_DEF_H_
-#define _WX_SQLITE3_DEF_H_
+#ifndef WX_SQLITE3_DEF_H_
+#define WX_SQLITE3_DEF_H_
 
 #if defined(WXMAKINGLIB_WXSQLITE3)
   #define WXDLLIMPEXP_SQLITE3
@@ -611,4 +745,4 @@ The following people have contributed to wxSQLite3:
   #define WXDLLIMPEXP_FWD_SQLITE3 WXDLLIMPEXP_SQLITE3
 #endif
 
-#endif // _WX_SQLITE3_DEF_H_
+#endif // WX_SQLITE3_DEF_H_
